summaryrefslogtreecommitdiff
path: root/include/linux/regulator
diff options
context:
space:
mode:
authorLaxman Dewangan <ldewangan@nvidia.com>2011-11-24 19:23:46 +0530
committerVarun Wadekar <vwadekar@nvidia.com>2011-12-08 16:53:33 +0530
commitd454cee86edac49aca7bdc1d2357e69adfe829ee (patch)
tree7cba30a2f92311f487a89ca8469d9c71f16207ac /include/linux/regulator
parentc0d0a8a770697079991a6338af01f86360c839f2 (diff)
mfd: tps80031: Support sleep configuration through platform data
Supporting the sleep configuration through platform data. Rearranging clock initialization to take external power control. Reviewed-on: http://git-master/r/67076 (cherry picked from commit 9da9d369bdbe988b98eec9b63085dfdb26de8237) Change-Id: I40c5a8608522dbc322e148b5d569e8f5a00faa21 Signed-off-by: Laxman Dewangan <ldewangan@nvidia.com> Reviewed-on: http://git-master/r/67331
Diffstat (limited to 'include/linux/regulator')
-rw-r--r--include/linux/regulator/tps80031-regulator.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/linux/regulator/tps80031-regulator.h b/include/linux/regulator/tps80031-regulator.h
index d84a8c48b4f0..1670d147fc3e 100644
--- a/include/linux/regulator/tps80031-regulator.h
+++ b/include/linux/regulator/tps80031-regulator.h
@@ -70,7 +70,7 @@ enum {
* @init_uV: initial micro volts which need to be set.
* @init_enable: Enable or do not enable the rails during initialization.
* @init_apply: Init parameter applied or not.
* @ext_pwr_ctrl: External power request control.
* @flags: Configuration flag to configure the rails. It should be ORed of
* above enums.
* @delay_us: Delay in microsecond after setting the desired voltage.
@@ -81,7 +81,7 @@ struct tps80031_regulator_platform_data {
int init_uV;
unsigned init_enable:1;
unsigned init_apply:1;
- unsigned int ext_pwr_ctrl;
+ unsigned int ext_ctrl_flag;
unsigned int flags;
int delay_us;
};
@@ -70,7 +70,7 @@ enum {
* @init_enable: Enable or do not enable the rails during initialization.
* @init_apply: Init parameter applied or not.
- * @ext_pwr_ctrl: External power request control.
+ * @ext_ctrl_flag: External control flag for sleep/power request control.
* @flags: Configuration flag to configure the rails. It should be ORed of
* above enums.